@@ -1,14 +1,14 @@
 #!/bin/sh
 #
-# Copyright (C) GFD Dennou Club, 2002.  All rights reserved.
+# Copyright (C) GFD Dennou Club, 2002-2005.  All rights reserved.
 #
 fc="`which ${FC:?}`"
-fflags="-I${MODINSTDIR:?} ${SYSFFLAGS}"
+fflags="-I${MODINSTDIR:?} ${SYSFFLAGS} ${FFLAGS}"
 libs="-L${LIBINSTDIR:?} -l${LIBNAME:?}"
 
-ldflags=${SYSLDFLAGS}
-ldlibs=${SYSLDLIBS:?}
-out=${1:-dclf90}
+ldflags="${SYSLDFLAGS} ${LDFLAGS}"
+ldlibs="${SYSLDLIBS:?} ${LDLIBS}"
+out=${1:-spmfrt}
 
 if [ ${F90MODTYPE:?} = intel.d ]; then
 	ldlibs=`echo $ldlibs | sed s/-lm//`
@@ -16,7 +16,36 @@ fi
 
 cat > $out <<EOF
 #!/bin/sh
+#=begin
+#== NAME
+#((* $out *)) -- script for fortran usin spml
+#
+#Wrapper shell script for fortran compiler using spml
+#
+#== SYNTAX
+#
+# % $out [fortran_compiler_option] fortran_program.f90
+#
+#== DESCRIPTION
+#
+#((* $out *)) is simple shell script.
+#This script set environment variables for using spml library.
+#
+#== OPTION
+#
+#:fortran_compiler_option
+#  commonly used fortran compiler option, see your fortran compiler manual
+#
+#== BUGS
+#
+#If you find a bug, please report it at SPMODEL Development Group
+#<dcstaff_(at)_gfd-dennou.org>
+#=end
 
+EOF
+
+
+cat >> $out <<EOF
 fc="$fc"
 fflags="$fflags"
 libs="$libs"
